#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
pub type UserDataTaskDataProviderConnection = *mut ::core::ffi::c_void;
pub type UserDataTaskDataProviderTriggerDetails = *mut ::core::ffi::c_void;
pub type UserDataTaskListCompleteTaskRequest = *mut ::core::ffi::c_void;
pub type UserDataTaskListCompleteTaskRequestEventArgs = *mut ::core::ffi::c_void;
pub type UserDataTaskListCreateOrUpdateTaskRequest = *mut ::core::ffi::c_void;
pub type UserDataTaskListCreateOrUpdateTaskRequestEventArgs = *mut ::core::ffi::c_void;
pub type UserDataTaskListDeleteTaskRequest = *mut ::core::ffi::c_void;
pub type UserDataTaskListDeleteTaskRequestEventArgs = *mut ::core::ffi::c_void;
pub type UserDataTaskListSkipOccurrenceRequest = *mut ::core::ffi::c_void;
pub type UserDataTaskListSkipOccurrenceRequestEventArgs = *mut ::core::ffi::c_void;
pub type UserDataTaskListSyncManagerSyncRequest = *mut ::core::ffi::c_void;
pub type UserDataTaskListSyncManagerSyncRequestEventArgs = *mut ::core::ffi::c_void;
