#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
#[cfg(feature = "Phone_Devices_Notification")]
pub mod Notification;
#[cfg(feature = "Phone_Devices_Power")]
pub mod Power;
