#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
pub type JET_API_PTR = usize;
pub type JET_HANDLE = usize;
pub type JET_INSTANCE = usize;
pub type JET_SESID = usize;
pub type JET_TABLEID = usize;
