#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
pub type IWindowsDevicesAllJoynBusAttachmentFactoryInterop = *mut ::core::ffi::c_void;
pub type IWindowsDevicesAllJoynBusAttachmentInterop = *mut ::core::ffi::c_void;
pub type IWindowsDevicesAllJoynBusObjectFactoryInterop = *mut ::core::ffi::c_void;
pub type IWindowsDevicesAllJoynBusObjectInterop = *mut ::core::ffi::c_void;
