#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
pub type ContactDataProviderConnection = *mut ::core::ffi::c_void;
pub type ContactDataProviderTriggerDetails = *mut ::core::ffi::c_void;
pub type ContactListCreateOrUpdateContactRequest = *mut ::core::ffi::c_void;
pub type ContactListCreateOrUpdateContactRequestEventArgs = *mut ::core::ffi::c_void;
pub type ContactListDeleteContactRequest = *mut ::core::ffi::c_void;
pub type ContactListDeleteContactRequestEventArgs = *mut ::core::ffi::c_void;
pub type ContactListServerSearchReadBatchRequest = *mut ::core::ffi::c_void;
pub type ContactListServerSearchReadBatchRequestEventArgs = *mut ::core::ffi::c_void;
pub type ContactListSyncManagerSyncRequest = *mut ::core::ffi::c_void;
pub type ContactListSyncManagerSyncRequestEventArgs = *mut ::core::ffi::c_void;
