#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
pub type LockApplicationHost = *mut ::core::ffi::c_void;
pub type LockScreenBadge = *mut ::core::ffi::c_void;
pub type LockScreenInfo = *mut ::core::ffi::c_void;
pub type LockScreenUnlockingDeferral = *mut ::core::ffi::c_void;
pub type LockScreenUnlockingEventArgs = *mut ::core::ffi::c_void;
