#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
pub type DetectedFace = *mut ::core::ffi::c_void;
pub type FaceDetector = *mut ::core::ffi::c_void;
pub type FaceTracker = *mut ::core::ffi::c_void;
